@@ -1,11 +1,14 @@
+/*******************************************
+ *	Functions on columns
+ *******************************************/
+
 #include "tile.h"
 
 extern char* columntools;
 
 /* Return the column enclosing 'tile', or 0 */
 Tile*
-tile_col(Tile*tile)
-{
+tile_col(Tile*tile){
 	if(tile && tile->ori != H)
 		tile = tile->up;
 	return tile;
@@ -13,8 +16,7 @@ tile_col(Tile*tile)
 
 /* Create and display a new column. */
 void
-col_new(View*v, char *arg)
-{
+col_new(View*v, char *arg) {
 	int	min, max;
 	Tile	*col;
 	Text	*tagt;
@@ -30,12 +32,12 @@ col_new(View*v, char *arg)
  * if we got them all.
  */
 static int
-col_delwins(Tile*tile)
-{
-	Tile	*t;
+col_delwins(Tile*tile) {
+	Tile	*t, *next;
 	int	problem = 0;
 
-	for(t = tile->down; t; t= t->right) {
+	for(t = tile->down; t; t= next) {
+		next = t->right;
 		if (win_del(t))
 			problem = 1;
 	}
@@ -43,8 +45,8 @@ col_delwins(Tile*tile)
 }
 
 void
-col_del(Tile*t)
-{
-	if(t && !col_delwins(t))
+col_del(Tile*t) {
+	if(t && !col_delwins(t)) {
 		tile_del(t);
+	}
 }
