@@ -1,3 +1,7 @@
+/*******************************************
+ *	Constant declarations
+ *******************************************/
+
 #include <sys/param.h>	/* for MAXPATHLEN */
 #ifndef DEFAULTSHELL
 #define DEFAULTSHELL "/bin/sh"
