@@ -1,3 +1,7 @@
+/*******************************************
+ *	the stuff a window represents (file, directory, type-script...)
+ *******************************************/
+
 #include <dirent.h>
 
 /*
