@@ -9,6 +9,12 @@ Path		wilydir;
 /* widget with most recent b1 click */
 View *	last_selection;
 
+/* 'last_focus' is a cache of the view we are pointing at,
+ * (we use point to type).  We update this only when we start
+ * typing after moving the pointer, or if the view is deleted.
+ */
+View	*last_focus;
+
 /* "stop" characters for various text expansions.
  * heuristic guesses only.
  */
