@@ -1,3 +1,7 @@
+/*******************************************
+ *	grow tiles by different amounts
+ *******************************************/
+
 #include "tile.h"
 /************************************************************
         Tile growth functions:
