@@ -1,3 +1,7 @@
+/*******************************************
+ *	Simple operations to apply to every visible tile in a list.
+ *******************************************/
+
 #include "tile.h"
 
 /********************************************************
