@@ -1,3 +1,7 @@
+/*******************************************
+ *	Handle messages from remote processes
+ *******************************************/
+
 #include "wily.h"
 #include "data.h"
 static char*	badrange ="bad range";
