@@ -1,3 +1,7 @@
+/*******************************************
+ *	geometry stuff for tiles and views
+ *******************************************/
+
 #include "tile.h"
 #include "view.h"
 
