@@ -1,3 +1,7 @@
+/*******************************************
+ *	Rune regular expression library--stolen from Sam
+ *******************************************/
+
 /* Copyright (c) 1992 AT&T - All rights reserved. */
 #include "sam.h"
 
