@@ -1,3 +1,7 @@
+/*******************************************
+ *	Maintain and monitor tags
+ *******************************************/
+
 #include "wily.h"
 #include "view.h"
 #include "text.h"
@@ -47,10 +51,14 @@ tag_settools(Text*t, char*s) {
 
 void
 tag_set(Text*t, char*s) {
+	View	*v;
+
 	assert(TEXT_ISTAG(t));
 
 	wily_modifying_tag = true;
 	text_replaceutf(t, text_all(t), s);
+	if ((v = text_view(t)))
+		v->anchor = text_length(t);
 	wily_modifying_tag = false;
 }
 
@@ -165,13 +173,12 @@ tag_findtool(Text*t, char*s)
  * most recently modified character.
  */
 void
-tag_modified(Text*t, ulong p)
-{
+tag_modified(Text*t, ulong p) {
 	Range	r;
 	Path		buf;
 	int		n;
 	
-	assert(t->data && !t->isbody);
+	assert(t->data && TEXT_ISTAG(t));
 	if( wily_modifying_tag)
 		return;
 	
