@@ -1,3 +1,7 @@
+/*******************************************
+ *	Includes a bunch of header files
+ *******************************************/
+
 #ifndef WILY_H
 #define WILY_H
 
